#!/bin/sh -efu
# ***** BEGIN LICENSE BLOCK *****
# * Copyright (C) 2007  Alexey Gladkov <legion@altlinux.org>
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
# ***** END LICENSE BLOCK *****

# NOTE: This hook must be executed before postinstall.d/65-setup-services.sh
# and postinstall.d/65-setup-control.sh:
# we are can change ntp service status and control state here.

. install2-init-functions
. shell-config
. shell-var

alteratordhcp_file="$destdir/var/lib/alterator/alterator-dhcp-general"

ntp_service_status_file=/var/cache/alterator/ntp_service.status
ntp_service=
ntp_control=
ntp_service_enabled=
ntp_service_mode=client

copy_conf()
{
	[ -f "$1" ] || return 0

	cp -af "$1" "$destdir/etc/"
	# Remove all dynamically added entries
	sed -i '/^# Generated by/,/^# End of/d' "$destdir/$1"
}

services_onoff()
{
	local name="$1"; shift
	local enabled="$1"; shift

	if [ -f /usr/share/install2/services-on ] || [ -f /usr/share/install2/services-off ]; then
		if [ -n "$enabled" ]; then
			add_file=/usr/share/install2/services-on
			del_file=/usr/share/install2/services-off
		else
			add_file=/usr/share/install2/services-off
			del_file=/usr/share/install2/services-on
		fi
		if [ -f "$del_file" ]; then
			sed -i "/^$name[[:blank:]]*$/d" "$del_file"
		fi
		grep -q "^$name[[:blank:]]*$" "$add_file" || \
			echo "$name" >>"$add_file"
	fi

	if [ -f /usr/share/install2/systemd-enabled ] || [ -f /usr/share/install2/systemd-enabled ]; then
		if [ -n "$enabled" ]; then
			add_file=/usr/share/install2/systemd-enabled
			del_file=/usr/share/install2/systemd-disabled
		else
			add_file=/usr/share/install2/systemd-disabled
			del_file=/usr/share/install2/systemd-enabled
		fi
		if [ -f "$del_file" ]; then
			sed -i -r "/^$name(\.service)?[[:blank:]]*$/d" "$del_file"
		fi
		grep -E -q "^$name(\.service)?[[:blank:]]*$" "$add_file" || \
			echo "$name".service >>"$add_file"
	fi
}


[ ! -f '/etc/localtime' ] ||
	cp -af '/etc/localtime' "$destdir/etc/"

[ ! -f '/etc/sysconfig/clock' ] || [ ! -f "$destdir/etc/sysconfig/clock" ] ||
	cp -af '/etc/sysconfig/clock' "$destdir/etc/sysconfig/"

[ ! -s '/etc/adjtime' ] ||
	cp -af '/etc/adjtime' "$destdir/etc/"


if shell_var_is_yes "$(shell_config_get "$ntp_service_status_file" enabled)"; then
	ntp_service_enabled=1
	if shell_var_is_yes "$(shell_config_get "$ntp_service_status_file" server)"; then
		ntp_service_mode=server
	fi
fi

if [ -f /etc/chrony.conf ]; then
	copy_conf /etc/chrony.conf
	copy_conf /etc/chrony.keys

	ntp_service=chronyd
	ntp_control=chrony
elif [ -f /etc/ntpd.conf ]; then
	copy_conf /etc/ntpd.conf

	ntp_service=ntpd
	ntp_control=ntpd
elif [ -f /etc/ntp.conf ]; then
	copy_conf /etc/ntp.conf

	ntp_service=ntpd
fi

if [ -n "$ntp_service_enabled" ]; then
	if [ -n "$ntp_control" ]; then
		if [ -f /usr/share/install2/control ]; then
			sed -i "/^$ntp_control[[:blank:]]/d" /usr/share/install2/control
		fi
		echo "$ntp_control $ntp_service_mode" >> /usr/share/install2/control
	fi

	## alterator-dhcp
	if [ -d "$destdir/etc/alterator/dhcp" ] && [ "$ntp_service_mode" = 'server' ]; then
		shell_config_set "$alteratordhcp_file" client_ntp "*"
	fi
fi

if [ -n "$ntp_service" ]; then
	# We can't just run chkconfig/systemctl here: this can be overwritten
	# by 65-setup-services.sh hook from installer. So change config files
	# for that hook instead.
	services_onoff "$ntp_service" "$ntp_service_enabled"
fi
